/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl;

import junit.framework.Assert;
import junit.framework.TestCase;


/**
 * This class contains the unit tests for {@link PersistenceConfigurationException}.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class PersistenceConfigurationExceptionTest extends TestCase {

    /**
     * This method tests the constructors of {@link PersistenceConfigurationException} using valid values and checks the
     * state of the instances created is as expected.
     */
    public void testConstructors() {
        final String causeMessge = "xy";
        final RuntimeException cause = new RuntimeException(causeMessge);
        //this message is generated automatically by BaseException constructor from cause parameter
        PersistenceConfigurationException persistenceConfigurationException;

        //design does specify null as valid message and as valid cause
        persistenceConfigurationException = new PersistenceConfigurationException(null);
        assertNull(persistenceConfigurationException.getMessage());
        assertNull(persistenceConfigurationException.getCause());

        final String message = "dummy";
        persistenceConfigurationException = new PersistenceConfigurationException(message);
        Assert.assertEquals(message, persistenceConfigurationException.getMessage());
        assertNull(persistenceConfigurationException.getCause());

        persistenceConfigurationException = new PersistenceConfigurationException(null, null);
        assertNull(persistenceConfigurationException.getMessage());
        assertNull(persistenceConfigurationException.getCause());

        persistenceConfigurationException = new PersistenceConfigurationException(message, null);
        Assert.assertEquals(message, persistenceConfigurationException.getMessage());
        assertNull(persistenceConfigurationException.getCause());

        persistenceConfigurationException = new PersistenceConfigurationException(null, cause);
        final String baseExceptionGeneratedCauseMessage = ", caused by " + causeMessge;
        Assert.assertEquals("null" + baseExceptionGeneratedCauseMessage,
            persistenceConfigurationException.getMessage());
        Assert.assertEquals(cause, persistenceConfigurationException.getCause());

        persistenceConfigurationException = new PersistenceConfigurationException(message, cause);
        Assert.assertEquals(message + baseExceptionGeneratedCauseMessage,
            persistenceConfigurationException.getMessage());
        Assert.assertEquals(cause, persistenceConfigurationException.getCause());
    }

}
