/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl.db;

import com.topcoder.db.connectionfactory.DBConnectionFactoryImpl;
import com.topcoder.document.index.persistence.AbstractTestForIndexPersistence;
import com.topcoder.document.index.persistence.IndexPersistence;
import com.topcoder.document.index.persistence.impl.PersistenceConfigurationException;


/**
 * This class contains all unit tests for {@link SimpleAccessDBIndexPersistence}.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class SimpleAccessDBIndexPersistenceTest extends AbstractTestForIndexPersistence {

    /**
     * This method tests {@link SimpleAccessDBIndexPersistence#SimpleAccessDBIndexPersistence(String)} for correctness.
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtor() throws Exception {
        new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
        loadSimpleConfiguration("simple_noConnectionName.xml");
        new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
        loadSimpleConfiguration("simple_emptyConnectionName.xml");
        new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
        loadSimpleConfiguration("simple_customConnectionClass.xml");
        new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the given namespace argument is  <tt>null</tt>
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailNull() throws Exception {
        try {
            new SimpleAccessDBIndexPersistence(null);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the given namespace argument is an empty String
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailEmpty() throws Exception {
        try {
            new SimpleAccessDBIndexPersistence("   ");
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: no configuration has been loaded
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailNoConfig() throws Exception {
        clearConfig();
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryNamespace is an empty String
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailEmptyConnectionFactoryNamespace() throws Exception {
        loadSimpleConfiguration("simple_emptyConnectionFactoryNamespace.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryNamespace does not exist
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailNoConnectionFactoryNamespace() throws Exception {
        loadSimpleConfiguration("simple_noConnectionFactoryNamespace.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryNamespace does not refer to a valid CM
     * namespace
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailInvalidConnectionFactoryNamespace() throws Exception {
        loadSimpleConfiguration("simple_invalidConnectionFactoryNamespace.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryClass refers to an unknown class
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailUnknownConnectionFactoryClass() throws Exception {
        loadSimpleConfiguration("simple_unknownConnectionFactoryClass.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryClass refers to a class that has no
     * matching constructor
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailNoMatchingCtorConnectionFactoryClass() throws Exception {
        loadSimpleConfiguration("simple_noMatchingCtorConnectionFactoryClass.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(String)}.
     * <p/>
     * <b>Failure reason</b>: the config manager property for connectionFactoryClass refers to a class that is of wrong
     * type
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testOneArgCtorFailWrongTypeConnectionFactoryClass() throws Exception {
        loadSimpleConfiguration("simple_wrongTypeConnectionFactoryClass.xml");
        try {
            new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (PersistenceConfigurationException expected) {
            //expected
        }
    }

    /**
     * This method tests {@link SimpleAccessDBIndexPersistence#SimpleAccessDBIndexPersistence(
     * com.topcoder.db.connectionfactory.DBConnectionFactory, String)} for correctness.
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testTwoArgCtor() throws Exception {
        new SimpleAccessDBIndexPersistence(new DBConnectionFactoryImpl(DEFAULT_DB_CONNECTION_FACTORY_NAMESPACE),
            "simple");
        new SimpleAccessDBIndexPersistence(new DBConnectionFactoryImpl(DEFAULT_DB_CONNECTION_FACTORY_NAMESPACE), "  ");
        new SimpleAccessDBIndexPersistence(new DBConnectionFactoryImpl(DEFAULT_DB_CONNECTION_FACTORY_NAMESPACE), null);
    }

    /**
     * This method tests the correct failure behavior of {@link SimpleAccessDBIndexPersistence#
     * SimpleAccessDBIndexPersistence(com.topcoder.db.connectionfactory.DBConnectionFactory, String)}.
     * <p/>
     * <b>Failure reason</b>: the given connectionFactory is <tt>null</tt>
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testTwoArgCtorFailNull() throws Exception {
        try {
            new SimpleAccessDBIndexPersistence(null, SIMPLE_DB_CONFIGURATION_NAMESPACE);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method creates the instance to be tested in the super class test cases.
     *
     * @return the instance to be tested
     *
     * @throws Exception in case some unexpected exception occurs
     */
    protected IndexPersistence createPersistenceInstance() throws Exception {
        return new SimpleAccessDBIndexPersistence(SIMPLE_DB_CONFIGURATION_NAMESPACE);
    }

    /**
     * This method does the test setup needed.
     *
     * @throws Exception in case some unexpected Exception occurs
     */
    protected void setUp() throws Exception {
        clearSimpleDatabase();
        super.setUp();
    }

    /**
     * This method does the cleanup after test run.
     *
     * @throws Exception in case some unexpected Exception occurs
     */
    protected void tearDown() throws Exception {
        super.tearDown();
        clearSimpleDatabase();
    }
}
